Learn R Programming

public.ctn0094extra (version 1.0.4)

loadRawData: Load Data Sets into a List

Description

Load Data Sets into a List

Usage

loadRawData(dataNames_char)

Value

Loads data sets specified into the current function environment for further evaluation (unused) and then returns these data sets as a named list

Arguments

dataNames_char

Names of data sets to load

Details

We may want to perform SQL-like operations on a set of tables without loading each table into R's Global Environment separately. This function loads these data sets into a self-destructing environment and then returns a named list of these data sets.

Examples

Run this code
   loadRawData(c("tlfb", "all_drugs"))

Run the code above in your browser using DataLab