Loads data sets specified into the current function environment for
further evaluation (unused) and then returns these data sets as a named
list
Arguments
dataNames_char
Names of data sets to load
Details
We may want to perform SQL-like operations on a set of tables
without loading each table into R's Global Environment separately. This
function loads these data sets into a self-destructing environment and
then returns a named list of these data sets.